@@ -10,7 +10,7 @@ use vars qw[$VERSION $COMMENT_NEST_LEVEL $STRINGIFY
 
 my $NOCACHE;
 
-$VERSION              = '1.896';
+$VERSION              = '1.897';
 $COMMENT_NEST_LEVEL ||= 2;
 $STRINGIFY          ||= 'format';
 $COLLAPSE_SPACES      = 1 unless defined $COLLAPSE_SPACES; # who wants //=? me!
@@ -30,7 +30,7 @@ Email::Address - RFC 2822 Address Parsing and Creation
 
 =head1 VERSION
 
-version 1.896
+version 1.897
 
 =head1 DESCRIPTION
 
@@ -228,8 +228,8 @@ sub parse {
           ($user, $host) = ($1, $2);
       }
 
-      return if $user =~ /\P{ASCII}/;
-      return if $host =~ /\P{ASCII}/;
+      next if $user =~ /\P{ASCII}/;
+      next if $host =~ /\P{ASCII}/;
 
       my ($phrase)       = /($display_name)/o;
 
@@ -441,7 +441,7 @@ sub _enquoted_phrase {
   return $phrase if $phrase =~ /\A=\?.+\?=\z/;
 
   $phrase =~ s/\A"(.+)"\z/$1/;
-  $phrase =~ s/\"/\\"/g;
+  $phrase =~ s/([\\"])/\\$1/g;
 
   return qq{"$phrase"};
 }
